# -*- coding: UTF-8 -*-
# @Time    : 2020/10/22
# @Author  : xiangyuejia@qq.com

from aitool.basic_function.time_function import exe_time as exe_time
